@@ -1,27 +1,15 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "grantleetheme.h"
-#include "grantleetheme_p.h"
 #include "grantleetheme_debug.h"
+#include "grantleetheme_p.h"
 #include "grantleethemeengine.h"
-#include <config-grantleetheme.h>
 #include "qtresourcetemplateloader.h"
+#include <config-grantleetheme.h>
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -68,7 +56,7 @@ void ThemePrivate::setupLoader()
     // Get the parent dir with themes, we set the theme directory separately
 
     QStringList templatePaths;
-    for (const QString &absolutePath : qAsConst(absolutePaths)) {
+    for (const QString &absolutePath : std::as_const(absolutePaths)) {
         QDir dir(absolutePath);
         dir.cdUp();
         templatePaths << dir.absolutePath();
@@ -97,19 +85,16 @@ Grantlee::Context ThemePrivate::createContext(const QVariantHash &data, const QB
 
 QString ThemePrivate::errorTemplate(const QString &reason, const QString &origTemplateName, const Grantlee::Template &failedTemplate)
 {
-    Grantlee::Template tpl = sEngine->newTemplate(
-        QStringLiteral("<h1>{{ error }}</h1>\n"
-                       "<b>%1:</b> {{ templateName }}<br>\n"
-                       "<b>%2:</b> {{ errorMessage }}")
-        .arg(i18n("Template"), i18n("Error message")),
-        QStringLiteral("TemplateError"));
+    Grantlee::Template tpl = sEngine->newTemplate(QStringLiteral("<h1>{{ error }}</h1>\n"
+                                                                 "<b>%1:</b> {{ templateName }}<br>\n"
+                                                                 "<b>%2:</b> {{ errorMessage }}")
+                                                      .arg(i18n("Template"), i18n("Error message")),
+                                                  QStringLiteral("TemplateError"));
 
     Grantlee::Context ctx = createContext();
     ctx.insert(QStringLiteral("error"), reason);
     ctx.insert(QStringLiteral("templateName"), origTemplateName);
-    const QString errorString = failedTemplate
-                                ? failedTemplate->errorString()
-                                : i18n("(null template)");
+    const QString errorString = failedTemplate ? failedTemplate->errorString() : i18n("(null template)");
     ctx.insert(QStringLiteral("errorMessage"), errorString);
     return tpl->render(&ctx);
 }
@@ -219,7 +204,8 @@ QString Theme::render(const QString &templateName, const QVariantHash &data, con
     Q_ASSERT(d->loader);
 
     if (!d->loader->canLoadTemplate(templateName)) {
-        qCWarning(GRANTLEETHEME_LOG) << "Cannot load template" << templateName << ", please check your installation. Tried in these dirs:" << d->loader->templateDirs();
+        qCWarning(GRANTLEETHEME_LOG) << "Cannot load template" << templateName
+                                     << ", please check your installation. Tried in these dirs:" << d->loader->templateDirs();
         return QString();
     }
 
