@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2019 Volker Krause <vkrause@kde.org>
+ * SPDX-FileCopyrightText: 2019 Volker Krause <vkrause@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "colorscheme.h"
@@ -22,8 +10,10 @@
 
 #include <KColorScheme>
 
-#define PROP_IMPL(PROP, METHOD) if (QString::compare(property, QLatin1String(#PROP), Qt::CaseInsensitive) == 0) \
-    { return object.METHOD(KColorScheme::PROP).color(); }
+#define PROP_IMPL(PROP, METHOD)                                                                                                                                \
+    if (QString::compare(property, QLatin1String(#PROP), Qt::CaseInsensitive) == 0) {                                                                          \
+        return object.METHOD(KColorScheme::PROP).color();                                                                                                      \
+    }
 #define BACKGROUND_PROP(PROP) PROP_IMPL(PROP, background)
 #define FOREGROUND_PROP(PROP) PROP_IMPL(PROP, foreground)
 #define DECORATION_PROP(PROP) PROP_IMPL(PROP, decoration)
